pub struct CompilerFixer { /* private fields */ }Expand description
Compiler error fixer Compiler error fixer
This struct handles parsing and fixing compilation errors from cargo check output. It can parse both JSON and text output formats and convert them into structured Diagnostic objects that can be used by the healing system.
Implementations
Sourceimpl CompilerFixer
impl CompilerFixer
Sourcepub fn parse_diagnostics(&self, output: &str) -> Vec<Diagnostic>
pub fn parse_diagnostics(&self, output: &str) -> Vec<Diagnostic>
Sourcepub async fn check(&self) -> Result<Vec<Diagnostic>>
pub async fn check(&self) -> Result<Vec<Diagnostic>>
Run cargo check and get diagnostics