pub fn load_memory_guidance_block(store: &MemoryStore) -> Option<String>Expand description
Build the memory guidance block to inject into the system prompt.
If the memory summary does not exist (or is empty), returns None.
pub fn load_memory_guidance_block(store: &MemoryStore) -> Option<String>Build the memory guidance block to inject into the system prompt.
If the memory summary does not exist (or is empty), returns None.