Module edit

Module edit 

Edit tool for precise string replacement

Structs

AppendFileTool
Tool for appending content to the end of a file
EditFileLinesTool
Tool for editing files by replacing a range of lines
EditFileTool
Tool for editing files with precise string replacement
InsertAfterTool
Tool for inserting text after a line matching a pattern. Safer than edit_file_lines for additions — never replaces existing content.