pub struct GitDiffTool { /* private fields */ }Expand description
Tool for getting git diff
This tool shows the differences between files in the working directory and the git index, or between commits.
Fields
workspace_root: The root directory of the workspace
Implementations