Result

Type Alias Result 

pub type Result<T> = Result<T, PawanError>;
Result type alias for Pawan operations

A convenience type alias that represents the result of Pawan operations, where success contains the desired value and failure contains a PawanError.

Aliased Type

pub enum Result<T> {
    Ok(T),
    Err(PawanError),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(PawanError)

Contains the error value