Edit tool for precise string replacement
Structs
- Append
File Tool - Tool for appending content to the end of a file
- Edit
File Lines Tool - Tool for editing files by replacing a range of lines
- Edit
File Tool - Tool for editing files with precise string replacement
- Insert
After Tool - Tool for inserting text after a line matching a pattern. Safer than edit_file_lines for additions — never replaces existing content.