pub type Result<T> = Result<T, PawanError>;Expand description
Result type alias for Pawan operations
A convenience type alias that represents the result of Pawan operations, where success contains the desired value and failure contains a PawanError.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(PawanError),
}